<?php
	require '../tmp/sql.php';
	require '../classes/mysql.php';
	
	$sql = new MySQL(); if ($sql->debug) error_reporting (E_ALL|E_STRICT); else error_reporting (0);
	
	require '../plugins/phpQuery.php';
	require '../classes/settings.php';
	require '../classes/security.php';
	require '../classes/functions.php';
	require '../classes/template.php';
	require '../classes/player.php';
	require '../classes/stats.php';
	
	$secure = new Security();
	$settings = new Settings();
	$player = new Player();
	$tpl = new Templates();
	$tpl->load_phrases("admin", true);
	date_default_timezone_set($settings->get("timezone"));
	
	
	### UPDATE DER SPIELER ###
	### UPDATE-LOGIK ###
	/*
		- Es werden $settings->updatecount Spieler auf einmal aktualisiert
		- Es werden erst die Spieler aktualisiert, bei denen $player->pushed = 1 ist
		- Danach werden die aktualisiert, deren $player->last_update am kleinsten ist
		
		- Spieler die gepusht sind, erhalten auf jeden Fall $player->update()                                                      / $player->pushed = 0
		- Spieler, deren $player->checkstate = "0" oder "notfound" ist, erhalten $player->push_sync()                              / $player->pushed = 1
		- Spieler, deren $player->date_check lnger zurck liegt, als $settings->synctime Stunden, erhalten $player->push_sync()   / $player->pushed = 1
		- Die restlichen Spieler erhalten $player->update()                                                                        / $player->pushed = 0
	*//*
		$result = Array(
			checkstate,
			update_left,
			push
		);
	*/
	
	
	// Standard-Variablen belegen
	$message = Array();
	$players = Array();
	$update_left = "unknown";
	$time = time();
	$synctime = (int)$settings->get('synctime'); $synctime = $synctime * 3600;
	if (isset($_POST['request']) AND $_POST['request'] == "admin") $type = "direct"; else $type = "cronjob"; // Wenn das Update aus dem Adminpanel heraus gestartet wird, wird es mit der API-Option "type=direct" belegt, und wird mit hherer Prioritt abgearbeitet
	
	
	// Abrufen und Speichern von IDENT und KEY fr den bf3stats-Server, wenn die Daten nicht whrend der Installation eingegeben wurden 
	// Das kann passieren, wenn der bf3stats.com-Server down ist
	if ($settings->get("key") == "" OR 
		$settings->get("key") == "invalid_name" OR 
		$settings->get("key") == "invalid_clientident" OR 
		$settings->get("key") == "ident_not_found" OR
		$settings->get("key") == "unknown_error" )
	{
		$data = Array(
			"test"      => "curl",
			"game"      => "c3", // Dies auch in "installer" ndern!
			"version"   => $settings->get('version').'*',
			"cms"       => $settings->get('cms'),
			"sig"       => $settings->get('signatures'),
			"baseurl"   => $_SERVER['HTTP_HOST'],
			"scripturl" => $_SERVER['HTTP_HOST']."/".str_replace($_SERVER['DOCUMENT_ROOT'], "", $_SERVER['SCRIPT_FILENAME'])
		);
		
		$ch = curl_init("http://curl.ezstats.org/");
		curl_setopt($ch, CURLOPT_POST, true); 
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); 
		curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
		$data = curl_exec($ch); curl_close($ch);
		$data = explode('||', $data);
		$settings->set("ident", $data[0], true);
		$settings->set("key", $data[1], true);
		//echo "<pre>";
		//print_r($data);
	}
	
	// Spieler abrufen, die gepusht sind
	$sql->query('
		SELECT id, name, platform, date_check, pushed, checkstate
		FROM '.$sql->prefix.'player
		WHERE id != 1
		AND pushed = "1"
		LIMIT '.$settings->get('updatecount').'
	');
	
	while ($row = $sql->fetchRow()) {
		$players[] = $row;
	}
	
	$left = $settings->get('updatecount') - count($players);
	if ($left > 0) {
		// Spieler abrufen, die am lngsten nicht mehr aktualisiert wurden
		$sql->query('
			SELECT id, name, platform, date_check, pushed, checkstate
			FROM '.$sql->prefix.'player
			WHERE id != 1
			ORDER BY last_update ASC
			LIMIT '.$left.'
		');
		
		while ($row = $sql->fetchRow()) {
			$players[] = $row;
		}
	}
	
	
	// Spieler aktualisieren
	foreach ($players as $array) {
		### Spieler war gepusht ###
		if ($array['pushed'] == "1") {
			$result = $player->update($array['id'], $array['name'], $array['platform']);
		}
		
		### Spieler ist noch nicht in der bf3stats-DB vorhanden ###
		else if ($array['checkstate'] == "0" OR $array['checkstate'] == "notfound") {
			$result = $player->push_sync($array['name'], $array['platform'], "direct");
		}
		
		### Letztes Update liegt lnger als "synctime" Stunden zurck
		else if (($time - $array['date_check']) > $synctime) {
			$result = $player->push_sync($array['name'], $array['platform'], $type);
		}
		
		### Spieler wird mit den bf3stats-Daten abgeglichen
		else {
			$result = $player->update($array['id'], $array['name'], $array['platform']);
		}
		
		
		// "update_left" protokollieren
		if($result['update_left'] !== NULL) $update_left = $result['update_left'];
		
		// Daten der Aktualisierung in die Spielereigenschaften schreiben
		$sql->query('
			UPDATE `'.$sql->prefix.'player` SET
				`last_update` = "'.$time.'",
				`checkstate`  = "'.$result['checkstate'].'",
				`pushed`      = "'.$result['push'].'"
			WHERE `id` = "'.$array['id'].'"
		');
		
		// Ergebnisnachricht schreiben
		$message[] = $array['name'].' ('.$result['checkstate'].')';
	}
	
	
	// "update_left" protokollieren
	$message[] = $tpl->phrase('update_left').$update_left;
	
	// Datum der Aktualisierung in die Settings schreiben
	$sql->query('UPDATE '.$sql->prefix.'settings SET value="'.$time.'" WHERE name = "lastcheckall"');
	
	
	// Ergebnis ausgeben
	if (isset ($_POST['request']) AND $_POST['request'] == "admin") {
		// Abruf aus dem Adminpanel heraus
		die (json_encode(array(
			"message" => $tpl->phrase('update_message').implode(", ", $message),
			"time" => date("d.m.Y - H:i", $time)
		)));
	} 
	else {
		// Direkter Abruf
		eval ("\$html = \"".$tpl->template("update")."\";");
		$html = phpQuery::newDocumentHTML($html);
		
		foreach ($message as $string) pq('ul')->append('<li>'.$string.'</li>');
		echo $html;
	}
?>